@@ -9,6 +9,10 @@ DEFAULT_TIMEOUT = 15
 _LOGGER = logging.getLogger(__name__)
 
 
+class InvalidToken(BaseException):
+    pass
+
+
 class Barry:
 
     def __init__(
@@ -19,7 +23,7 @@ class Barry:
         self.access_token = access_token
         self.timeout = timeout
 
-    def update_price_data(self):
+    def update_price_data(self, check_token=False):
         current_time = datetime.now().replace(microsecond=0).isoformat() + 'Z'
         last_hour_date_time = (datetime.now() - timedelta(hours=1)).replace(microsecond=0).isoformat() + 'Z'
         headers = {
@@ -32,5 +36,9 @@ class Barry:
 
         response = requests.post('https://jsonrpc.barry.energy/json-rpc', headers=headers, data=data)
         json_res = response.json()
-        if json_res.get('result'):
-            return json_res['result'][0]['value']
+        if check_token:
+            if not json_res.get('result'):
+                raise InvalidToken('Invalid access token')
+        else:
+            if json_res.get('result'):
+                return json_res['result'][0]['value']
